.. ldap2jira documentation master file, created by
   sphinx-quickstart on Wed Mar  3 14:15:10 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ldap2jira's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. automodule:: ldap2jira.map
   :members:

.. automodule:: ldap2jira.ldap_lookup
   :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
